@@ -1,6 +1,6 @@
 /* Copyright (C) 2002, 2003 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: init_sockfd.h,v 1.2 2004/06/16 21:11:52 mmj Exp $
+ * $Id: init_sockfd.h,v 1.3 2005/02/08 18:13:14 mmj Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -24,6 +24,6 @@
 #ifndef INIT_SOCKFD_H
 #define INIT_SOCKFD_H
 
-void init_sockfd(int *sockfd, const char *relayhost);
+void init_sockfd(int *sockfd, const char *relayhost, unsigned short port);
 
 #endif /* INIT_SOCKFD_H */
