@@ -1,6 +1,6 @@
 /* Copyright (C) 2004 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: prepstdreply.h,v 1.7 2007/06/13 20:54:41 mortenp Exp $
+ * $Id: prepstdreply.h,v 1.8 2007/11/05 21:23:37 mortenp Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -25,12 +25,13 @@
 #define PREPSTDREPLY_H
 
 char *substitute(const char *line, const char *listaddr, const char *listdelim,
-		 size_t datacount, char **data);
+		size_t datacount, char **data, const char* mailname);
 char *substitute_one(const char *line, const char *listaddr,
-		 const char *listdelim, size_t datacount, char **data);
+		const char *listdelim, size_t datacount, char **data,
+		const char* mailname);
 int open_listtext(const char *listdir, const char *filename);
 char *prepstdreply(const char *listdir, const char *filename, const char *from,
-		   const char *to, const char *replyto, size_t tokencount,
-		   char **data, char *customheaders);
+		const char *to, const char *replyto, size_t tokencount,
+		char **data, char *customheaders, const char *mailname);
 
 #endif /* PREPSTDREPLY_H */
