@@ -1,6 +1,6 @@
 /* Copyright (C) 2004 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: send_help.h,v 1.3 2004/06/16 21:11:53 mmj Exp $
+ * $Id: send_help.h,v 1.4 2006/12/06 21:29:27 mortenp Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -25,6 +25,6 @@
 #define SEND_HELP_H
 
 void send_help(const char *listdir, const char *emailaddr,
-	       const char *mlmmjsend);
+	       const char *mlmmjsend, const char *name, const char *textfile);
 
 #endif
