@@ -1,6 +1,6 @@
 /* Copyright (C) 2002, 2003 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: strgen.h,v 1.8 2005/01/15 10:46:12 mmj Exp $
+ * $Id: strgen.h,v 1.9 2007/06/10 18:05:01 mortenp Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -34,7 +34,7 @@ char *hostnamestr(void);
 char *mydirname(const char *path);
 char *mybasename(const char *path);
 char *cleanquotedp(const char *qpstr);
-char *genmsgid(void);
+char *genmsgid(const char *fqdn);
 char *gendatestr(void);
 
 #endif /* STRGEN_H */
