@@ -1,6 +1,6 @@
 /* Copyright (C) 2002, 2003 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: chomp.c,v 1.3 2004/08/11 22:29:38 mmj Exp $
+ * $Id: chomp.c,v 1.5 2006/09/12 19:57:45 mortenp Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -31,9 +31,14 @@ char *chomp(char *str)
 	if(str == NULL)
 		return NULL;
 
+	if(*str == '\0' || *str == '\n') {
+		*str = '\0';
+		return str;
+	}
+
 	i = strlen(str) - 1;
 
-	while(str[i] == '\n') {
+	while((str[i] == '\n') || (str[i] == '\r')) {
 		str[i] = 0;
 		i--;
 	}
