@@ -1,6 +1,6 @@
 /* Copyright (C) 2003 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: listcontrol.c,v 1.53 2007/09/27 07:49:57 mmj Exp $
+ * $Id: listcontrol.c,v 1.54 2009/04/11 08:27:36 mmj Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -716,7 +716,7 @@ int listcontrol(struct email_container *fromemails, const char *listdir,
 		owner_idx = -1;
 		owners = ctrlvalues(listdir, "owner");
 		for(i = 0; i < owners->count; i++) {
-			if(strcmp(fromemails->emaillist[0],
+			if(strcasecmp(fromemails->emaillist[0],
 						owners->strs[i]) == 0) {
 				log_oper(listdir, OPLOGFNAME,
 						"%s requested sub list",
