@@ -1,6 +1,6 @@
 /* Copyright (C) 2004, 2005 Morten K. Poulsen <morten at afdelingp.dk>
  *
- * $Id: send_digest.c,v 1.13 2007/06/13 20:54:41 mortenp Exp $
+ * $Id: send_digest.c,v 1.14 2007/11/05 21:23:37 mortenp Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -263,7 +263,7 @@ int send_digest(const char *listdir, int firstindex, int lastindex,
 		utfsub = unistr_escaped_to_utf8(line + 9);
 	}
 
-	utfsub2 = substitute(utfsub, listaddr, listdelim, 5, subst_data);
+	utfsub2 = substitute(utfsub, listaddr, listdelim, 5, subst_data, NULL);
 	subject = unistr_utf8_to_header(utfsub2);
 	myfree(utfsub);
 	myfree(utfsub2);
@@ -362,7 +362,7 @@ errdighdrs:
 				myfree(line);
 
 				tmp = substitute(utfline, listaddr, listdelim,
-						5, subst_data);
+						5, subst_data, NULL);
 				myfree(utfline);
 
 				if(writen(fd, tmp, strlen(tmp)) < 0) {
